Gentelella Alela! |

Welcome,

## John Doe

### Projects Listing design

## Projects

Simple table with project listing with progress and editing options

# | Project Name | Team Members | Project Progress | Status | #Edit
--- | --- | --- | --- | --- | ---
# | Pesamakini Backend UI Created 01.01.2015 |  | 57% Complete |  | View Edit Delete
# | Pesamakini Backend UI Created 01.01.2015 |  | 47% Complete |  | View Edit Delete
# | Pesamakini Backend UI Created 01.01.2015 |  | 77% Complete |  | View Edit Delete
# | Pesamakini Backend UI Created 01.01.2015 |  | 60% Complete |  | View Edit Delete
# | Pesamakini Backend UI Created 01.01.2015 |  | 12% Complete |  | View Edit Delete
# | Pesamakini Backend UI Created 01.01.2015 |  | 35% Complete |  | View Edit Delete
# | Pesamakini Backend UI Created 01.01.2015 |  | 87% Complete |  | View Edit Delete
# | Pesamakini Backend UI Created 01.01.2015 |  | 77% Complete |  | View Edit Delete